Coverage for F:\DEV\EMIZ\emiz\mission_time.py: 0%

# Coverage for F:\DEV\EMIZ\emiz\mission_time.py : 0%

## 20 statements 0 run 20 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 | # coding=utf-8 import datetime import shutil import logging from emiz.miz import Miz LOGGER = logging.getLogger('EMIZ').getChild(__name__) class MissionTime: def __init__(self, moment: datetime.datetime): self.moment = moment print(moment.strftime('%d/%m/%Y %H:%M:%S')) def mission_start_time(self): return self.moment.strftime('%d/%m/%Y %H:%M:%S') if __name__ == '__main__': time = MissionTime(datetime.datetime.now()) with Miz('./test/test_files/time.miz') as miz: miz._encode() shutil.copy(miz.mission_file, './test/test_files/time/input') miz.mission.mission_start_time_as_date = time.mission_start_time() miz._encode() shutil.copy(miz.mission_file, './test/test_files/time/output') miz.zip('./test/test_files/time_output.miz')